@@ -1,3 +1,4 @@
+from os import terminal_size
 from pathlib import Path
 
 import pytest
@@ -9,6 +10,7 @@ WIDGET_EXAMPLES_DIR = Path("../../docs/examples/widgets")
 LAYOUT_EXAMPLES_DIR = Path("../../docs/examples/guide/layout")
 STYLES_EXAMPLES_DIR = Path("../../docs/examples/styles")
 SNAPSHOT_APPS_DIR = Path("./snapshot_apps")
+CLI_PREVIEWS_DIR = Path("../../src/textual/cli/previews")
 
 
 # --- Layout related stuff ---
@@ -163,6 +165,16 @@ def test_radio_set_example(snap_compare):
     assert snap_compare(WIDGET_EXAMPLES_DIR / "radio_set.py")
 
 
+def test_content_switcher_example_initial(snap_compare):
+    assert snap_compare(WIDGET_EXAMPLES_DIR / "content_switcher.py")
+
+
+def test_content_switcher_example_switch(snap_compare):
+    assert snap_compare(WIDGET_EXAMPLES_DIR / "content_switcher.py", press=[
+        "tab", "tab", "enter", "wait:500"
+    ], terminal_size=(50, 50))
+
+
 # --- CSS properties ---
 # We have a canonical example for each CSS property that is shown in their docs.
 # If any of these change, something has likely broken, so snapshot each of them.
@@ -219,6 +231,25 @@ def test_programmatic_scrollbar_gutter_change(snap_compare):
     )
 
 
+# --- CLI Preview Apps ---
+# For our CLI previews e.g. `textual easing`, `textual colors` etc, we have snapshots
+
+def test_borders_preview(snap_compare):
+    assert snap_compare(CLI_PREVIEWS_DIR / "borders.py", press=["tab", "enter"])
+
+
+def test_colors_preview(snap_compare):
+    assert snap_compare(CLI_PREVIEWS_DIR / "colors.py")
+
+
+def test_easing_preview(snap_compare):
+    assert snap_compare(CLI_PREVIEWS_DIR / "easing.py")
+
+
+def test_keys_preview(snap_compare):
+    assert snap_compare(CLI_PREVIEWS_DIR / "keys.py", press=["a", "b"])
+
+
 # --- Other ---
 
 
@@ -240,6 +271,11 @@ def test_label_widths(snap_compare):
     assert snap_compare(SNAPSHOT_APPS_DIR / "label_widths.py")
 
 
+def test_border_alpha(snap_compare):
+    """Test setting a border alpha."""
+    assert snap_compare(SNAPSHOT_APPS_DIR / "border_alpha.py")
+
+
 def test_auto_width_input(snap_compare):
     assert snap_compare(
         SNAPSHOT_APPS_DIR / "auto_width_input.py", press=["tab", *"Hello"]
